# Changelog

All notable changes to this project will be documented in this file.

## [unreleased]

### 🚀 Features

- Add s3 support on cli (table-version)
- Add s3 cli parameters to remaining commands

### 🐛 Bug Fixes

- Remove logs for cli runner's sake
- Add condition on table_type for cli
- Python versions
- Rye path
- Rye path
- Add moto path
- Tests
- Skip moto_server tests
- More makefile awesomeness
- Again
- Grep binary
- Tests with moto
- Tests and name
- Correct classifiers

### 📚 Documentation

- Add CHANGELOG
- Update changelog
- Update README
- Update readme
- Update Readme
- Update readme
- Update todo commands in readme
- Update readme
- Update readme
- Ci status badge
- Update readme
- Update readme
- Update url in readme
- Add python classifiers
- Update more permissive license in readme

### ⚙️ Miscellaneous Tasks

- Bump version
- Version mgmt
- Bump version
- Bump version
- Create pipeline
- Add coverage
- Correct repo url
- Repo from var
- Fix branch name
- Enable workflow_dispatch
- Bump version
- Test tests
- Good enough
- Bump version
- Bump version
- Bump version

<!-- generated by git-cliff -->
